@@ -1,7 +1,7 @@
 /* gok-page-feedbacks.c
 *
-* Copyright 2002 Sun Microsystems, Inc.,
-* Copyright 2002 University Of Toronto
+* Copyright 2002-2009 Sun Microsystems, Inc.,
+* Copyright 2002-2009 University Of Toronto
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
@@ -409,23 +409,17 @@ void gok_page_feedbacks_button_clicked_change_name ()
 
 	/* create the 'new feedbacks name' dialog */
 	pDialogChangeName = gtk_dialog_new_with_buttons (_("GOK Feedback Name"),
-												GTK_WINDOW(gok_settingsdialog_get_window()),
-												GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-												GTK_STOCK_OK, GTK_RESPONSE_OK,
-												GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL, NULL);
+							 GTK_WINDOW(gok_settingsdialog_get_window()),
+							 GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+							 GTK_STOCK_OK, GTK_RESPONSE_OK,
+							 GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL, NULL);
 	/* add a text label */
 	pLabel = gtk_label_new (_("Change the feedback name:"));
-	gtk_widget_ref (pLabel);
-	gtk_object_set_data_full (GTK_OBJECT (pDialogChangeName), "pLabel", pLabel,
-                            (GtkDestroyNotify) gtk_widget_unref);
 	gtk_widget_show (pLabel);
 	gtk_box_pack_start (GTK_BOX(GTK_DIALOG (pDialogChangeName)->vbox), pLabel, FALSE, FALSE, 0);
 
 	/* add a text entry */
 	pEntryNewName = gtk_entry_new ();
-	gtk_widget_ref (pEntryNewName);
-	gtk_object_set_data_full (GTK_OBJECT (pDialogChangeName), "Entry", pEntryNewName,
-                            (GtkDestroyNotify) gtk_widget_unref);
 	gtk_entry_set_text (GTK_ENTRY(pEntryNewName), m_pFeedbackCurrent->pDisplayName);
 	gtk_widget_show (pEntryNewName);
 	gtk_box_pack_start (GTK_BOX(GTK_DIALOG (pDialogChangeName)->vbox), pEntryNewName, FALSE, FALSE, 0);
@@ -447,6 +441,7 @@ void gok_page_feedbacks_button_clicked_change_name ()
 		/* check if the new feedback name is empty */
 		if (strlen (pNewName) == 0)
 		{
+			/*** TODO: code duplication ***/
 			pDialog = gtk_message_dialog_new (GTK_WINDOW(pDialogChangeName),
 				GTK_DIALOG_DESTROY_WITH_PARENT,
 				GTK_MESSAGE_ERROR,
@@ -466,6 +461,7 @@ void gok_page_feedbacks_button_clicked_change_name ()
 			{
 				if (strcmp (pFeedback->pDisplayName, pNewName) == 0)
 				{
+					/*** TODO: code duplication ***/
 					pDialog = gtk_message_dialog_new (GTK_WINDOW(pDialogChangeName),
 						GTK_DIALOG_DESTROY_WITH_PARENT,
 						GTK_MESSAGE_ERROR,
@@ -640,6 +636,7 @@ void gok_page_feedbacks_button_clicked_delete ()
 
 	sprintf (buffer, _("Do you wish to delete this feedback (%s)?"), pNameFeedback);
 
+	/*** TODO: code duplication ***/
 	pDialog = gtk_message_dialog_new ((GtkWindow*)gok_settingsdialog_get_window(),
 			GTK_DIALOG_DESTROY_WITH_PARENT,
 			GTK_MESSAGE_QUESTION,
